ufolint
=======

A Unified Font Object (UFO) source file linter for typeface development.  ufolint was developed to support continuous integration testing of source contributions to typeface projects that use UFO source code.

Documentation and issue reporting are available on the `GitHub repository <https://github.com/source-foundry/ufolint>`_ .

